==> aaa_elflibs-13.37-x86_64-7.txz: install/doinst.sh <==
( cd lib64 ; rm -rf libfuse.so.2 )
( cd lib64 ; ln -sf libfuse.so.2.8.5 libfuse.so.2 )
( cd lib64 ; rm -rf libbz2.so.1 )
( cd lib64 ; ln -sf libbz2.so.1.0 libbz2.so.1 )
( cd lib64 ; rm -rf liblzma.so.0 )
( cd lib64 ; ln -sf liblzma.so.0.0.0 liblzma.so.0 )
( cd lib64 ; rm -rf libncurses.so.5 )
( cd lib64 ; ln -sf libncurses.so.5.9 libncurses.so.5 )
( cd lib64 ; rm -rf libacl.so.1 )
( cd lib64 ; ln -sf libacl.so.1.1.0 libacl.so.1 )
( cd lib64 ; rm -rf libtermcap.so.2 )
( cd lib64 ; ln -sf libtermcap.so.2.0.8 libtermcap.so.2 )
( cd lib64 ; rm -rf libattr.so.1 )
( cd lib64 ; ln -sf libattr.so.1.1.0 libattr.so.1 )
( cd lib64 ; rm -rf libpopt.so.0 )
( cd lib64 ; ln -sf libpopt.so.0.0.0 libpopt.so.0 )
( cd lib64 ; rm -rf libdm.so.0 )
( cd lib64 ; ln -sf libdm.so.0.0.4 libdm.so.0 )
( cd lib64 ; rm -rf libcap.so.2 )
( cd lib64 ; ln -sf libcap.so.2.20 libcap.so.2 )
( cd lib64 ; rm -rf libsysfs.so.2 )
( cd lib64 ; ln -sf libsysfs.so.2.0.1 libsysfs.so.2 )
( cd lib64 ; rm -rf libgpm.so.1 )
( cd lib64 ; ln -sf libgpm.so.1.19.0 libgpm.so.1 )
( cd lib64 ; rm -rf libbz2.so.1.0 )
( cd lib64 ; ln -sf libbz2.so.1.0.6 libbz2.so.1.0 )
( cd lib64 ; rm -rf libncursesw.so.5 )
( cd lib64 ; ln -sf libncursesw.so.5.9 libncursesw.so.5 )
( cd usr/lib64 ; rm -rf libmpfr.so.1 )
( cd usr/lib64 ; ln -sf libmpfr.so.1.2.2 libmpfr.so.1 )
( cd usr/lib64 ; rm -rf libtiff.so.3 )
( cd usr/lib64 ; ln -sf libtiff.so.3.9.4 libtiff.so.3 )
( cd usr/lib64 ; rm -rf libvga.so.1 )
( cd usr/lib64 ; ln -sf libvga.so.1.9.25 libvga.so.1 )
( cd usr/lib64 ; rm -rf libidn.so.11 )
( cd usr/lib64 ; ln -sf libidn.so.11.6.2 libidn.so.11 )
( cd usr/lib64 ; rm -rf libelf.so.0 )
( cd usr/lib64 ; ln -sf libelf.so.0.8.13 libelf.so.0 )
( cd usr/lib64 ; rm -rf libusb-0.1.so.4 )
( cd usr/lib64 ; ln -sf libusb-0.1.so.4.4.4 libusb-0.1.so.4 )
( cd usr/lib64 ; rm -rf libz.so.1 )
( cd usr/lib64 ; ln -sf libz.so.1.2.5 libz.so.1 )
( cd usr/lib64 ; rm -rf libmenuw.so.5 )
( cd usr/lib64 ; ln -sf libmenuw.so.5.9 libmenuw.so.5 )
( cd usr/lib64 ; rm -rf libpng.so.14 )
( cd usr/lib64 ; ln -sf libpng14.so.14 libpng.so.14 )
( cd usr/lib64 ; rm -rf libldap-2.4.so.2 )
( cd usr/lib64 ; ln -sf libldap-2.4.so.2.5.6 libldap-2.4.so.2 )
( cd usr/lib64 ; rm -rf libglib-2.0.so.0 )
( cd usr/lib64 ; ln -sf libglib-2.0.so.0.2800.6 libglib-2.0.so.0 )
( cd usr/lib64 ; rm -rf libslang.so.1 )
( cd usr/lib64 ; ln -sf libslang.so.1.4.9 libslang.so.1 )
( cd usr/lib64 ; rm -rf libgmp.so.3 )
( cd usr/lib64 ; ln -sf libgmp.so.3.4.4 libgmp.so.3 )
( cd usr/lib64 ; rm -rf libgmpxx.so.4 )
( cd usr/lib64 ; ln -sf libgmpxx.so.4.2.1 libgmpxx.so.4 )
( cd usr/lib64 ; rm -rf libcurl.so.4 )
( cd usr/lib64 ; ln -sf libcurl.so.4.2.0 libcurl.so.4 )
( cd usr/lib64 ; rm -rf libhistory.so.5 )
( cd usr/lib64 ; ln -sf libhistory.so.5.2 libhistory.so.5 )
( cd usr/lib64 ; rm -rf libpcre.so.0 )
( cd usr/lib64 ; ln -sf libpcre.so.0.0.1 libpcre.so.0 )
( cd usr/lib64 ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgobject-2.0.so.0.2800.6 libgobject-2.0.so.0 )
( cd usr/lib64 ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgthread-2.0.so.0.2800.6 libgthread-2.0.so.0 )
( cd usr/lib64 ; rm -rf libpanel.so.5 )
( cd usr/lib64 ; ln -sf libpanel.so.5.9 libpanel.so.5 )
( cd usr/lib64 ; rm -rf libgmp.so.10 )
( cd usr/lib64 ; ln -sf libgmp.so.10.0.1 libgmp.so.10 )
( cd usr/lib64 ; rm -rf libjpeg.so.62 )
( cd usr/lib64 ; ln -sf libjpeg.so.62.0.0 libjpeg.so.62 )
( cd usr/lib64 ; rm -rf libpcreposix.so.0 )
( cd usr/lib64 ; ln -sf libpcreposix.so.0.0.0 libpcreposix.so.0 )
( cd usr/lib64 ; rm -rf liblber-2.3.so.0 )
( cd usr/lib64 ; ln -sf liblber-2.3.so.0.2.31 liblber-2.3.so.0 )
( cd usr/lib64 ; rm -rf libpng12.so.0 )
( cd usr/lib64 ; ln -sf libpng12.so.0.44.0 libpng12.so.0 )
( cd usr/lib64 ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgmodule-2.0.so.0.2800.6 libgmodule-2.0.so.0 )
( cd usr/lib64 ; rm -rf libreadline.so.5 )
( cd usr/lib64 ; ln -sf libreadline.so.5.2 libreadline.so.5 )
( cd usr/lib64 ; rm -rf libldap-2.3.so.0 )
( cd usr/lib64 ; ln -sf libldap-2.3.so.0.2.31 libldap-2.3.so.0 )
( cd usr/lib64 ; rm -rf libjpeg.so.8 )
( cd usr/lib64 ; ln -sf libjpeg.so.8.0.1 libjpeg.so.8 )
( cd usr/lib64 ; rm -rf libvgagl.so.1 )
( cd usr/lib64 ; ln -sf libvgagl.so.1.9.25 libvgagl.so.1 )
( cd usr/lib64 ; rm -rf libformw.so.5 )
( cd usr/lib64 ; ln -sf libformw.so.5.9 libformw.so.5 )
( cd usr/lib64 ; rm -rf libmp.so.3 )
( cd usr/lib64 ; ln -sf libmp.so.3.1.21 libmp.so.3 )
( cd usr/lib64 ; rm -rf libpng.so.3 )
( cd usr/lib64 ; ln -sf libpng.so.3.44.0 libpng.so.3 )
( cd usr/lib64 ; rm -rf libmm.so.14 )
( cd usr/lib64 ; ln -sf libmm.so.14.0.22 libmm.so.14 )
( cd usr/lib64 ; rm -rf libltdl.so.7 )
( cd usr/lib64 ; ln -sf libltdl.so.7.3.0 libltdl.so.7 )
( cd usr/lib64 ; rm -rf libexpat.so.1 )
( cd usr/lib64 ; ln -sf libexpat.so.1.5.2 libexpat.so.1 )
( cd usr/lib64 ; rm -rf libfreetype.so.6 )
( cd usr/lib64 ; ln -sf libfreetype.so.6.6.2 libfreetype.so.6 )
( cd usr/lib64 ; rm -rf libpng14.so.14 )
( cd usr/lib64 ; ln -sf libpng14.so.14.5.0 libpng14.so.14 )
( cd usr/lib64 ; rm -rf liblber-2.4.so.2 )
( cd usr/lib64 ; ln -sf liblber-2.4.so.2.5.6 liblber-2.4.so.2 )
( cd usr/lib64 ; rm -rf libform.so.5 )
( cd usr/lib64 ; ln -sf libform.so.5.9 libform.so.5 )
( cd usr/lib64 ; rm -rf libpanelw.so.5 )
( cd usr/lib64 ; ln -sf libpanelw.so.5.9 libpanelw.so.5 )
( cd usr/lib64 ; rm -rf libmenu.so.5 )
( cd usr/lib64 ; ln -sf libmenu.so.5.9 libmenu.so.5 )
( cd usr/lib64 ; rm -rf libltdl.so.3 )
( cd usr/lib64 ; ln -sf libltdl.so.3.1.6 libltdl.so.3 )
( cd usr/lib64 ; rm -rf libasound.so.2 )
( cd usr/lib64 ; ln -sf libasound.so.2.0.0 libasound.so.2 )
( cd usr/lib64 ; rm -rf libgdbm.so.3 )
( cd usr/lib64 ; ln -sf libgdbm.so.3.0.0 libgdbm.so.3 )
( cd usr/lib64 ; rm -rf libusb-1.0.so.0 )
( cd usr/lib64 ; ln -sf libusb-1.0.so.0.0.0 libusb-1.0.so.0 )
( cd usr/lib64 ; rm -rf libslang.so.2 )
( cd usr/lib64 ; ln -sf libslang.so.2.2.3 libslang.so.2 )

==> aaa_elflibs-14.0-x86_64-4.txz: install/doinst.sh <==
( cd lib64 ; rm -rf libbz2.so.1 )
( cd lib64 ; ln -sf libbz2.so.1.0 libbz2.so.1 )
( cd lib64 ; rm -rf libbz2.so.1.0 )
( cd lib64 ; ln -sf libbz2.so.1.0.6 libbz2.so.1.0 )
( cd lib64 ; rm -rf libtermcap.so.2 )
( cd lib64 ; ln -sf libtermcap.so.2.0.8 libtermcap.so.2 )
( cd lib64 ; rm -rf libncursesw.so.5 )
( cd lib64 ; ln -sf libncursesw.so.5.9 libncursesw.so.5 )
( cd lib64 ; rm -rf liblzma.so.5 )
( cd lib64 ; ln -sf liblzma.so.5.0.4 liblzma.so.5 )
( cd lib64 ; rm -rf libacl.so.1 )
( cd lib64 ; ln -sf libacl.so.1.1.0 libacl.so.1 )
( cd lib64 ; rm -rf libdm.so.0 )
( cd lib64 ; ln -sf libdm.so.0.0.4 libdm.so.0 )
( cd lib64 ; rm -rf libsysfs.so.2 )
( cd lib64 ; ln -sf libsysfs.so.2.0.1 libsysfs.so.2 )
( cd lib64 ; rm -rf libncurses.so.5 )
( cd lib64 ; ln -sf libncurses.so.5.9 libncurses.so.5 )
( cd lib64 ; rm -rf libattr.so.1 )
( cd lib64 ; ln -sf libattr.so.1.1.0 libattr.so.1 )
( cd lib64 ; rm -rf libgpm.so.1 )
( cd lib64 ; ln -sf libgpm.so.1.19.0 libgpm.so.1 )
( cd lib64 ; rm -rf libpopt.so.0 )
( cd lib64 ; ln -sf libpopt.so.0.0.0 libpopt.so.0 )
( cd lib64 ; rm -rf libz.so.1 )
( cd lib64 ; ln -sf libz.so.1.2.6 libz.so.1 )
( cd lib64 ; rm -rf libfuse.so.2 )
( cd lib64 ; ln -sf libfuse.so.2.8.5 libfuse.so.2 )
( cd lib64 ; rm -rf libcap.so.2 )
( cd lib64 ; ln -sf libcap.so.2.22 libcap.so.2 )
( cd usr/lib64 ; rm -rf libmenuw.so.5 )
( cd usr/lib64 ; ln -sf libmenuw.so.5.9 libmenuw.so.5 )
( cd usr/lib64 ; rm -rf libltdl.so.3 )
( cd usr/lib64 ; ln -sf libltdl.so.3.1.6 libltdl.so.3 )
( cd usr/lib64 ; rm -rf libslang.so.2 )
( cd usr/lib64 ; ln -sf libslang.so.2.2.3 libslang.so.2 )
( cd usr/lib64 ; rm -rf libtalloc.so.2 )
( cd usr/lib64 ; ln -sf libtalloc.so.2.0.5 libtalloc.so.2 )
( cd usr/lib64 ; rm -rf libusb-0.1.so.4 )
( cd usr/lib64 ; ln -sf libusb-0.1.so.4.4.4 libusb-0.1.so.4 )
( cd usr/lib64 ; rm -rf libasound.so.2 )
( cd usr/lib64 ; ln -sf libasound.so.2.0.0 libasound.so.2 )
( cd usr/lib64 ; rm -rf libpanel.so.5 )
( cd usr/lib64 ; ln -sf libpanel.so.5.9 libpanel.so.5 )
( cd usr/lib64 ; rm -rf libjpeg.so.62 )
( cd usr/lib64 ; ln -sf libjpeg.so.62.0.0 libjpeg.so.62 )
( cd usr/lib64 ; rm -rf libgmp.so.10 )
( cd usr/lib64 ; ln -sf libgmp.so.10.0.5 libgmp.so.10 )
( cd usr/lib64 ; rm -rf libmenu.so.5 )
( cd usr/lib64 ; ln -sf libmenu.so.5.9 libmenu.so.5 )
( cd usr/lib64 ; rm -rf libelf.so.0 )
( cd usr/lib64 ; ln -sf libelf.so.0.8.13 libelf.so.0 )
( cd usr/lib64 ; rm -rf libjpeg.so.8 )
( cd usr/lib64 ; ln -sf libjpeg.so.8.0.1 libjpeg.so.8 )
( cd usr/lib64 ; rm -rf libglib-2.0.so.0 )
( cd usr/lib64 ; ln -sf libglib-2.0.so.0.3200.4 libglib-2.0.so.0 )
( cd usr/lib64 ; rm -rf libusb-1.0.so.0 )
( cd usr/lib64 ; ln -sf libusb-1.0.so.0.1.0 libusb-1.0.so.0 )
( cd usr/lib64 ; rm -rf libvgagl.so.1 )
( cd usr/lib64 ; ln -sf libvgagl.so.1.9.25 libvgagl.so.1 )
( cd usr/lib64 ; rm -rf libcurl.so.4 )
( cd usr/lib64 ; ln -sf libcurl.so.4.2.0 libcurl.so.4 )
( cd usr/lib64 ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgmodule-2.0.so.0.3200.4 libgmodule-2.0.so.0 )
( cd usr/lib64 ; rm -rf libreadline.so.5 )
( cd usr/lib64 ; ln -sf libreadline.so.5.2 libreadline.so.5 )
( cd usr/lib64 ; rm -rf libltdl.so.7 )
( cd usr/lib64 ; ln -sf libltdl.so.7.3.0 libltdl.so.7 )
( cd usr/lib64 ; rm -rf libpanelw.so.5 )
( cd usr/lib64 ; ln -sf libpanelw.so.5.9 libpanelw.so.5 )
( cd usr/lib64 ; rm -rf libtiff.so.3 )
( cd usr/lib64 ; ln -sf libtiff.so.3.9.6 libtiff.so.3 )
( cd usr/lib64 ; rm -rf libidn.so.11 )
( cd usr/lib64 ; ln -sf libidn.so.11.6.8 libidn.so.11 )
( cd usr/lib64 ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgobject-2.0.so.0.3200.4 libgobject-2.0.so.0 )
( cd usr/lib64 ; rm -rf libpcreposix.so.0 )
( cd usr/lib64 ; ln -sf libpcreposix.so.0.0.0 libpcreposix.so.0 )
( cd usr/lib64 ; rm -rf libform.so.5 )
( cd usr/lib64 ; ln -sf libform.so.5.9 libform.so.5 )
( cd usr/lib64 ; rm -rf libpng14.so.14 )
( cd usr/lib64 ; ln -sf libpng14.so.14.12.0 libpng14.so.14 )
( cd usr/lib64 ; rm -rf liblber-2.4.so.2 )
( cd usr/lib64 ; ln -sf liblber-2.4.so.2.8.3 liblber-2.4.so.2 )
( cd usr/lib64 ; rm -rf libpng.so.14 )
( cd usr/lib64 ; ln -sf libpng14.so.14 libpng.so.14 )
( cd usr/lib64 ; rm -rf libgmp.so.3 )
( cd usr/lib64 ; ln -sf libgmp.so.3.4.4 libgmp.so.3 )
( cd usr/lib64 ; rm -rf libpng12.so.0 )
( cd usr/lib64 ; ln -sf libpng12.so.0.50.0 libpng12.so.0 )
( cd usr/lib64 ; rm -rf libpcre.so.0 )
( cd usr/lib64 ; ln -sf libpcre.so.0.0.1 libpcre.so.0 )
( cd usr/lib64 ; rm -rf libexpat.so.1 )
( cd usr/lib64 ; ln -sf libexpat.so.1.5.2 libexpat.so.1 )
( cd usr/lib64 ; rm -rf libformw.so.5 )
( cd usr/lib64 ; ln -sf libformw.so.5.9 libformw.so.5 )
( cd usr/lib64 ; rm -rf libhistory.so.5 )
( cd usr/lib64 ; ln -sf libhistory.so.5.2 libhistory.so.5 )
( cd usr/lib64 ; rm -rf libmm.so.14 )
( cd usr/lib64 ; ln -sf libmm.so.14.0.22 libmm.so.14 )
( cd usr/lib64 ; rm -rf libmp.so.3 )
( cd usr/lib64 ; ln -sf libmp.so.3.1.25 libmp.so.3 )
( cd usr/lib64 ; rm -rf libpng.so.3 )
( cd usr/lib64 ; ln -sf libpng.so.3.50.0 libpng.so.3 )
( cd usr/lib64 ; rm -rf libgdbm.so.3 )
( cd usr/lib64 ; ln -sf libgdbm.so.3.0.0 libgdbm.so.3 )
( cd usr/lib64 ; rm -rf libfreetype.so.6 )
( cd usr/lib64 ; ln -sf libfreetype.so.6.9.0 libfreetype.so.6 )
( cd usr/lib64 ; rm -rf libslang.so.1 )
( cd usr/lib64 ; ln -sf libslang.so.1.4.9 libslang.so.1 )
( cd usr/lib64 ; rm -rf libvga.so.1 )
( cd usr/lib64 ; ln -sf libvga.so.1.9.25 libvga.so.1 )
( cd usr/lib64 ; rm -rf libmpfr.so.1 )
( cd usr/lib64 ; ln -sf libmpfr.so.1.2.2 libmpfr.so.1 )
( cd usr/lib64 ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgthread-2.0.so.0.3200.4 libgthread-2.0.so.0 )
( cd usr/lib64 ; rm -rf libldap-2.4.so.2 )
( cd usr/lib64 ; ln -sf libldap-2.4.so.2.8.3 libldap-2.4.so.2 )
( cd usr/lib64 ; rm -rf libgmpxx.so.4 )
( cd usr/lib64 ; ln -sf libgmpxx.so.4.2.5 libgmpxx.so.4 )
